.. py:module:: momotor.shared.doc

======================
``momotor.shared.doc``
======================

Documentation helpers

Class documentation
===================

.. automodule:: momotor.shared.doc
   :members:
